==> stack-2.1.3-27-x86_64.pkg.tar.xz: usr/share/haskell/register/stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stack
version: 2.1.3
id: stack-2.1.3-AwpciZ8FKet3vEnWAgC83r
key: stack-2.1.3-AwpciZ8FKet3vEnWAgC83r
license: BSD-3-Clause
maintainer: manny@fpcomplete.com
author: Commercial Haskell SIG
homepage: http://haskellstack.org
synopsis: The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.
    .
    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.
    .
    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.
category: Development
abi: 089113f53a6bd905e16cd9628fcc6a91
exposed: True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.Freeze Stack.GhcPkg Stack.Ghci
    Stack.Ghci.Script Stack.Hoogle Stack.IDE Stack.Init Stack.Lock
    Stack.Ls Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.FreezeParser Stack.Options.GhcBuildParser
    Stack.Options.GhcVariantParser Stack.Options.GhciParser
    Stack.Options.GlobalParser Stack.Options.HaddockParser
    Stack.Options.HpcReportParser Stack.Options.LogLevelParser
    Stack.Options.NewParser Stack.Options.NixParser
    Stack.Options.PackageParser Stack.Options.ResolverParser
    Stack.Options.SDistParser Stack.Options.ScriptParser
    Stack.Options.TestParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version
    Stack.Types.VersionIntervals Stack.Unpack Stack.Upgrade
    Stack.Upload System.Info.ShortPathName System.Permissions
    System.Process.Pager System.Terminal
hidden-modules: Stack.Types.Cache System.Uname
import-dirs: /usr/lib/ghc-8.6.5/site-local/stack-2.1.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/stack-2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/stack-2.1.3
hs-libraries: HSstack-2.1.3-AwpciZ8FKet3vEnWAgC83r
depends:
    Cabal-2.4.0.1 aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    annotated-wl-pprint-0.7.0-DGkZQ2VEej1K9q8cmlJu7D
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj array-0.5.3.0
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 colour-2.3.5-y0xjV3ONUd40VuBtReEvC
    conduit-1.3.1.1-6wGhn7vdA3B6uXWcLIr87M
    conduit-extra-1.3.4-K6FXFWghk929uw0H6vW1f containers-0.6.0.1
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    cryptonite-conduit-0.2.2-BCacdClaDrDurmhP9V6zT deepseq-1.4.4.0
    directory-1.3.3.0 echo-0.1.3-ECiqPOMwsmlLdGbSgLjbPY
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    extra-1.6.18-Hvb5V9crxyzC6wVibsyssz
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    filelock-0.1.1.3-FiB0yXqMtv43yiGSEcPU8N filepath-1.4.2.1
    fsnotify-0.3.0.1-7Iyw8902uvFRto4XeaNIA
    generic-deriving-1.12.4-35jn1EpQs9wLkrWud50div
    hackage-security-0.5.3.0-BRvLWPjeAMBHmRNJmFQnO
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hi-file-parser-0.1.0.0-ikfZ0mH3FKCjNeirJXPZD
    hpack-0.32.0-BQHJ3MiueDE7870liX4B1h hpc-0.6.0.3
    http-client-0.6.4-5F3g2gtRkbJCEu8wzvrA41
    http-client-tls-0.3.5.3-1Aiha9XpRrMDnWLpJT85yp
    http-conduit-2.3.7.1-B08ieaTirROJ2iGsVG2V8n
    http-download-0.1.0.0-HiejYDocmTNJA2iXEF91nq
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    microlens-0.4.11.2-Ecy0HNwIglV6pyNsLPomsR
    mintty-0.1.2-H8nsJd1PqbAKjPWVQrDTEK
    mono-traversable-1.0.12.0-2ZvK6RvZ1aSIDuV8Uz5kAc mtl-2.2.2
    mustache-2.3.0-7lNVQfCFSfd4dZ26tnoDVz
    neat-interpolation-0.3.2.4-3gQ0RJWxfoYGQ1vvgoHAVi
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    open-browser-0.2.1.0-JBhinIwNmWr8AQilwoAYz4
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    pantry-0.1.1.1-fUHmxNlhGr7Qpfga9ZQhi
    path-0.6.1-Dbf4RfDrHofHtc1bqSTwwN
    path-io-1.4.2-LC2bphiRDgqLbnvsCG1r2G
    persistent-2.10.1-3og9MAC29gi7KTjTVnXGs7
    persistent-sqlite-2.10.5-7l6vhWpSfSa3xElzjbV6y3
    persistent-template-2.7.2-8Gl01jzfB6PEfWmBa1GH5C pretty-1.1.3.6
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    project-template-0.2.0.1-7szQuQ1Z4CdHH7k0LSl2sF
    regex-applicative-text-0.1.0.1-HKGYqmzzE0PDKBIWaLupue
    resource-pool-0.2.3.2-gJbLOXkUsfHOTyD1xpnwB
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    retry-0.8.0.1-1nFgjSWZCgvG6N6kCMoJ9K
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    rio-prettyprint-0.1.0.0-JAD1qWV1ZUkEVIURfaM5Yw
    split-0.2.3.3-6ARGTwZCeo0EpQtAl0OgPz stm-2.5.0.0
    streaming-commons-0.2.1.1-28hNvoSsYHXJrd00KOHsX9
    tar-0.5.1.1-3qunMRDwYpBL5Ol3li52ue template-haskell-2.14.0.0
    temporary-1.3-F6xRo1rNLbCADrAA6svjLo
    terminal-size-0.3.2.1-Hh6hFaOyLfiJ6x0AenX2yY text-1.2.3.1
    text-metrics-0.3.0-9zUVorhgsUa80G4sTQ4ins
    th-reify-many-0.1.9-AO2I3KZjoiS9IDtUI7zilG time-1.8.0.2
    tls-1.4.1-6TnmZspMoZnGCLYoHYo6Yp transformers-0.5.6.2
    typed-process-0.2.6.0-IWCaVP4NRIgGqzHPmtZrv3
    unicode-transforms-0.3.6-8605YU3Kxnm9V56PWkgPCT unix-2.7.2.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.1.2-KISqh17fCa88c3vzjvDXPU
    zip-archive-0.4.1-6wSxciqkc43Cn55hmSsvpi
    zlib-0.6.2.1-Aknvu72a6qHHNTLcHtkXd
haddock-interfaces: /usr/share/doc/stack/html/stack.haddock
haddock-html: /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stack-2.1.3-28-x86_64.pkg.tar.xz: usr/share/haskell/register/stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stack
version: 2.1.3
id: stack-2.1.3-3gme7XeuZCQ8RwH4TSAVLd
key: stack-2.1.3-3gme7XeuZCQ8RwH4TSAVLd
license: BSD-3-Clause
maintainer: manny@fpcomplete.com
author: Commercial Haskell SIG
homepage: http://haskellstack.org
synopsis: The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.
    .
    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.
    .
    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.
category: Development
abi: 92df466438d1d35bb1b29912e9154e6d
exposed: True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.Freeze Stack.GhcPkg Stack.Ghci
    Stack.Ghci.Script Stack.Hoogle Stack.IDE Stack.Init Stack.Lock
    Stack.Ls Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.FreezeParser Stack.Options.GhcBuildParser
    Stack.Options.GhcVariantParser Stack.Options.GhciParser
    Stack.Options.GlobalParser Stack.Options.HaddockParser
    Stack.Options.HpcReportParser Stack.Options.LogLevelParser
    Stack.Options.NewParser Stack.Options.NixParser
    Stack.Options.PackageParser Stack.Options.ResolverParser
    Stack.Options.SDistParser Stack.Options.ScriptParser
    Stack.Options.TestParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version
    Stack.Types.VersionIntervals Stack.Unpack Stack.Upgrade
    Stack.Upload System.Info.ShortPathName System.Permissions
    System.Process.Pager System.Terminal
hidden-modules: Stack.Types.Cache System.Uname
import-dirs: /usr/lib/ghc-8.6.5/site-local/stack-2.1.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/stack-2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/stack-2.1.3
hs-libraries: HSstack-2.1.3-3gme7XeuZCQ8RwH4TSAVLd
depends:
    Cabal-2.4.0.1 aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    annotated-wl-pprint-0.7.0-DGkZQ2VEej1K9q8cmlJu7D
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj array-0.5.3.0
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 colour-2.3.5-y0xjV3ONUd40VuBtReEvC
    conduit-1.3.1.1-6wGhn7vdA3B6uXWcLIr87M
    conduit-extra-1.3.4-K6FXFWghk929uw0H6vW1f containers-0.6.0.1
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    cryptonite-conduit-0.2.2-BCacdClaDrDurmhP9V6zT deepseq-1.4.4.0
    directory-1.3.3.0 echo-0.1.3-ECiqPOMwsmlLdGbSgLjbPY
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    extra-1.6.18-Hvb5V9crxyzC6wVibsyssz
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    filelock-0.1.1.3-FiB0yXqMtv43yiGSEcPU8N filepath-1.4.2.1
    fsnotify-0.3.0.1-7Iyw8902uvFRto4XeaNIA
    generic-deriving-1.12.4-35jn1EpQs9wLkrWud50div
    hackage-security-0.5.3.0-BRvLWPjeAMBHmRNJmFQnO
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hi-file-parser-0.1.0.0-ikfZ0mH3FKCjNeirJXPZD
    hpack-0.32.0-BQHJ3MiueDE7870liX4B1h hpc-0.6.0.3
    http-client-0.6.4-5F3g2gtRkbJCEu8wzvrA41
    http-client-tls-0.3.5.3-1Aiha9XpRrMDnWLpJT85yp
    http-conduit-2.3.7.1-B08ieaTirROJ2iGsVG2V8n
    http-download-0.1.0.0-HiejYDocmTNJA2iXEF91nq
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    microlens-0.4.11.2-Ecy0HNwIglV6pyNsLPomsR
    mintty-0.1.2-H8nsJd1PqbAKjPWVQrDTEK
    mono-traversable-1.0.12.0-2ZvK6RvZ1aSIDuV8Uz5kAc mtl-2.2.2
    mustache-2.3.0-7lNVQfCFSfd4dZ26tnoDVz
    neat-interpolation-0.3.2.4-3gQ0RJWxfoYGQ1vvgoHAVi
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    open-browser-0.2.1.0-JBhinIwNmWr8AQilwoAYz4
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    pantry-0.1.1.1-fUHmxNlhGr7Qpfga9ZQhi
    path-0.6.1-Dbf4RfDrHofHtc1bqSTwwN
    path-io-1.4.2-LC2bphiRDgqLbnvsCG1r2G
    persistent-2.10.1-3og9MAC29gi7KTjTVnXGs7
    persistent-sqlite-2.10.5-7l6vhWpSfSa3xElzjbV6y3
    persistent-template-2.7.2-8Gl01jzfB6PEfWmBa1GH5C pretty-1.1.3.6
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    project-template-0.2.0.1-7szQuQ1Z4CdHH7k0LSl2sF
    regex-applicative-text-0.1.0.1-HKGYqmzzE0PDKBIWaLupue
    resource-pool-0.2.3.2-gJbLOXkUsfHOTyD1xpnwB
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    retry-0.8.0.1-1nFgjSWZCgvG6N6kCMoJ9K
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    rio-prettyprint-0.1.0.0-JAD1qWV1ZUkEVIURfaM5Yw
    split-0.2.3.3-6ARGTwZCeo0EpQtAl0OgPz stm-2.5.0.0
    streaming-commons-0.2.1.1-28hNvoSsYHXJrd00KOHsX9
    tar-0.5.1.1-3qunMRDwYpBL5Ol3li52ue template-haskell-2.14.0.0
    temporary-1.3-F6xRo1rNLbCADrAA6svjLo
    terminal-size-0.3.2.1-Hh6hFaOyLfiJ6x0AenX2yY text-1.2.3.1
    text-metrics-0.3.0-9zUVorhgsUa80G4sTQ4ins
    th-reify-many-0.1.9-AO2I3KZjoiS9IDtUI7zilG time-1.8.0.2
    tls-1.4.1-6TnmZspMoZnGCLYoHYo6Yp transformers-0.5.6.2
    typed-process-0.2.6.0-IWCaVP4NRIgGqzHPmtZrv3
    unicode-transforms-0.3.6-8605YU3Kxnm9V56PWkgPCT unix-2.7.2.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.1.2-KISqh17fCa88c3vzjvDXPU
    zip-archive-0.4.1-6wSxciqkc43Cn55hmSsvpi
    zlib-0.6.2.1-Aknvu72a6qHHNTLcHtkXd
haddock-interfaces: /usr/share/doc/stack/html/stack.haddock
haddock-html: /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
